@@ -142,7 +142,10 @@ class Path(str):
     .. seealso:: :mod:`os.path`
     """
 
-    def __init__(self, other=''):
+    def __new__(cls, other='.'):
+        return super().__new__(cls, other)
+
+    def __init__(self, other='.'):
         if other is None:
             raise TypeError("Invalid initial value for path: None")
         with contextlib.suppress(AttributeError):
@@ -674,7 +677,11 @@ class Path(str):
 
         Converts all newline sequences to ``\n``.
         """
-        warnings.warn(".text is deprecated; use read_text", DeprecationWarning)
+        warnings.warn(
+            ".text is deprecated; use read_text",
+            DeprecationWarning,
+            stacklevel=2,
+        )
         return U_NEWLINE.sub('\n', self.read_text(encoding, errors))
 
     def write_text(
@@ -1217,8 +1224,7 @@ class Path(str):
         """Set the access/modified times of this file to the current time.
         Create the file if it does not exist.
         """
-        fd = os.open(self, os.O_WRONLY | os.O_CREAT, 0o666)
-        os.close(fd)
+        os.close(os.open(self, os.O_WRONLY | os.O_CREAT, 0o666))
         os.utime(self, None)
         return self
 
@@ -1422,30 +1428,22 @@ class Path(str):
             errors=errors,
             newline=newline,
         )
-        try:
-            perm = os.fstat(readable.fileno()).st_mode
-        except OSError:
-            writable = self.open(
-                'w' + mode.replace('r', ''),
-                buffering=buffering,
-                encoding=encoding,
-                errors=errors,
-                newline=newline,
-            )
-        else:
-            os_mode = os.O_CREAT | os.O_WRONLY | os.O_TRUNC
-            os_mode |= getattr(os, 'O_BINARY', 0)
-            fd = os.open(self, os_mode, perm)
-            writable = open(
-                fd,
-                "w" + mode.replace('r', ''),
-                buffering=buffering,
-                encoding=encoding,
-                errors=errors,
-                newline=newline,
-            )
-            with contextlib.suppress(OSError, AttributeError):
-                self.chmod(perm)
+
+        perm = os.stat(readable.fileno()).st_mode
+        os_mode = os.O_CREAT | os.O_WRONLY | os.O_TRUNC
+        os_mode |= getattr(os, 'O_BINARY', 0)
+        fd = os.open(self, os_mode, perm)
+        writable = open(
+            fd,
+            "w" + mode.replace('r', ''),
+            buffering=buffering,
+            encoding=encoding,
+            errors=errors,
+            newline=newline,
+        )
+        with contextlib.suppress(OSError, AttributeError):
+            self.chmod(perm)
+
         try:
             yield readable, writable
         except Exception:
